/// # The JSON:API Client.
///
/// The client works on top of Dart's built-in HTTP client.
/// ```dart
/// import 'package:http/http.dart';
/// import 'package:json_api/client.dart';
///
/// void main() async {
///   final httpClient = Client();
///   final jsonApiClient = JsonApiClient(httpClient);
///   final url = Uri.parse('http://localhost:8080/companies/2');
///   final response = await jsonApiClient.fetchCollection(url);
///   httpClient.close(); // Don't forget to close the http client
///   print('The collection page size is ${response.data.collection.length}');
///   final resource = response.data.unwrap().first;
///   print('The last element is ${resource}');
///   resource.attributes.forEach((k, v) => print('Attribute $k is $v'));
/// }
/// ```
///
/// The client provides a set of methods to deal with resources and relationships.
/// - Fetching
///   - [JsonApiClient.fetchCollection] - resource collection, either primary or related
///   - [JsonApiClient.fetchResource] - a single resource, either primary or related
///   - [JsonApiClient.fetchRelationship] - a generic relationship (either to-one, to-many or even incomplete)
///   - [JsonApiClient.fetchToOne] - a to-one relationship
///   - [JsonApiClient.fetchToMany] - a to-many relationship
/// - Manipulating resources
///   - [JsonApiClient.createResource] - creates a new primary resource
///   - [JsonApiClient.updateResource] - updates the existing resource by its type and id
///   - [JsonApiClient.deleteResource] - deletes the existing resource
/// - Manipulating relationships
///   - [JsonApiClient.replaceToOne] - replaces the existing to-one relationship with a new resource identifier
///   - [JsonApiClient.deleteToOne] - deletes the existing to-one relationship by setting the resource identifier to null
///   - [JsonApiClient.replaceToMany] - replaces the existing to-many relationship with the given set of resource identifiers
///   - [JsonApiClient.addToMany] - adds the given identifiers to the existing to-many relationship
///
library client;

export 'package:json_api/src/client/client_document_factory.dart';
export 'package:json_api/src/client/json_api_client.dart';
export 'package:json_api/src/client/response.dart';
export 'package:json_api/src/client/status_code.dart';
